/*
 * main.c
 *
 *  Created on: Jun 28, 2016
 *      Author: tbaruah
 */

#include "main.h"
#include <sys/platform.h>
#include <stdint.h>
#include <stdbool.h>
#include <stddef.h>
#include <stdio.h>
#include "adi_initialize.h"
#include <services/pwr/adi_pwr.h>
#include "mode.h"
#include "SPI.h"

#define MHZTOHZ       (1000000)
#define CLKIN         (25  * MHZTOHZ)
#define CORE_MAX      (500 * MHZTOHZ)
#define SYS_MAX       (125 * MHZTOHZ)
#define VCO_MIN       (72  * MHZTOHZ)

/**********************************************************************************************************************************************************
 Function: main()
 Author:   Trinayan Baruah
 Purpose:  This function calls the function that initializes SPI communication, clocks and then runs a while loop for collecting ADC samples
 **********************************************************************************************************************************************************/
int main(int argc, char *argv[])
{
	adi_initComponents();
	uint32_t gpioMaxCallbacks;
	adi_gpio_Init((void*)gpioMemory, GPIO_MEMORY_SIZE, &gpioMaxCallbacks);
	adi_gpio_SetDirection(ADI_GPIO_PORT_A, ADI_GPIO_PIN_0, ADI_GPIO_DIRECTION_OUTPUT); //Initialize Pin for CFG

	CGU_Init();

	InitSpiPinmux();
	Init_SPI_AD7689();

	uint16_t read_data1;
	while (1)  //We are collecting around 1000 samples here
	{
#ifdef RAC  //If using RAC

		adi_gpio_Set(ADI_GPIO_PORT_A, ADI_GPIO_PIN_0); // CNV High
		for(int i = 0; i < 180; i++); // Wait until end of tconv before pulling CNV low
		adi_gpio_Clear(ADI_GPIO_PORT_A, ADI_GPIO_PIN_0); //CNV Low
		for(int i =0; i < 30 ; i++);
		read_data1 = Init_SPI_Transfer((0x3C41) << 2); //Sending CFG 0x3C41 . Left shifted by 2 because CFG is 14 bit register
		for(int j =0; j < 500; j++); // Wait for sometime before starting next conversion . Time between conversions is minimum 4 us
	    printf("read_data1 %d \n", read_data1);

#endif


#ifndef RAC  // This is code for RDC mode

		adi_gpio_Set(ADI_GPIO_PORT_A, ADI_GPIO_PIN_0);  // CNV High
		adi_gpio_Clear(ADI_GPIO_PORT_A, ADI_GPIO_PIN_0);// CNV Low
        read_data1=Init_SPI_Transfer((0x3C41) << 2);	//Sending CFG 0x3C41 . Left shifted by 2 because CFG is 14 bit register
        for(int i=0; i < 30; i++);
		adi_gpio_Set(ADI_GPIO_PORT_A, ADI_GPIO_PIN_0);  //CNV High
		for(int x = 0; x<100; x++);						//Wait until end of CNV
		adi_gpio_Clear(ADI_GPIO_PORT_A, ADI_GPIO_PIN_0); //CNV low
        for(int x =0; x <500; x++);
        printf("read_data1 %d \n", read_data1);

#endif

	}

	printf(" Conversion Done");
}

/**********************************************************************************************************************************************************
 Function: CGU_Init()
 Author:   Trinayan Baruah
 Purpose:  This function initializes the different CGU Settings

 **********************************************************************************************************************************************************/
void CGU_Init()
{
	adi_pwr_Init(0,CLKIN);
	adi_pwr_SetPowerMode(0u,ADI_PWR_MODE_FULL_ON);
	adi_pwr_SetClkControlRegister(0,ADI_PWR_CLK_CTL_MSEL, ADI_CFG_MSEL_VALUE);
	adi_pwr_SetClkControlRegister(0,ADI_PWR_CLK_CTL_DF, ADI_CFG_DF_VALUE);
	adi_pwr_SetClkDivideRegister(0,ADI_PWR_CLK_DIV_CSEL, ADI_CFG_DIV_CSEL);
	adi_pwr_SetClkDivideRegister(0,ADI_PWR_CLK_DIV_SYSSEL, ADI_CFG_DIV_SYSSEL);
	adi_pwr_SetClkDivideRegister(0,ADI_PWR_CLK_DIV_S0SEL, ADI_CFG_DIV_S0SEL);
	adi_pwr_SetClkDivideRegister(0, ADI_PWR_CLK_DIV_UPDT,  1);
}
